@@ -8,9 +8,10 @@ import (
 	printerstorage "k8s.io/kubernetes/pkg/printers/storage"
 
 	"github.com/openshift/api/user"
-	printersinternal "github.com/openshift/openshift-apiserver/pkg/printers/internalversion"
+
 	userapi "github.com/openshift/openshift-apiserver/pkg/user/apis/user"
 	"github.com/openshift/openshift-apiserver/pkg/user/apiserver/registry/group"
+	userprinters "github.com/openshift/openshift-apiserver/pkg/user/printers/internalversion"
 )
 
 // REST implements a RESTStorage for groups against etcd
@@ -25,7 +26,7 @@ func NewREST(optsGetter generic.RESTOptionsGetter) (*REST, error) {
 		NewListFunc:              func() runtime.Object { return &userapi.GroupList{} },
 		DefaultQualifiedResource: user.Resource("groups"),
 
-		TableConvertor: printerstorage.TableConvertor{TablePrinter: printers.NewTablePrinter().With(printersinternal.AddHandlers)},
+		TableConvertor: printerstorage.TableConvertor{TableGenerator: printers.NewTableGenerator().With(userprinters.AddUserOpenShiftHandler)},
 
 		CreateStrategy: group.Strategy,
 		UpdateStrategy: group.Strategy,
